from kivy.app import App
from kivy.uix.widget import Widget
from kivy.graphics import Rectangle

from kivy.core.image import ImageLoader
from kivy.cache import Cache

imageloader = ImageLoader()
Cache.register('ctpug', limit=200)

def _load(filename):
   '''Load an object either from disk or from the cache.

      We rely on kivy's caching infrastructure'''
   obj = Cache.get('ctpug', filename)
   if obj is None:
       obj = imageloader.load(filename)
       Cache.append('ctpug', filename, obj)
   return obj.texture



class TileWidget(Widget):

    def __init__(self):
        super(TileWidget, self).__init__(size=(64, 64))
        self.texture = _load('cwall.png')
        self.pos = (200, 200)
        self.scale = 1.0
        self.touches = []
        self.cur_dist = 0
        with self.canvas:
            self.rect = Rectangle(pos=self.pos, size=(256*self.scale, 256*self.scale), texture=self.texture)

    def redraw(self):
        #self.canvas.clear()
        #with self.canvas:
        #    Rectangle(pos=self.pos, size=(256*self.scale, 256*self.scale), texture=self.texture)
        self.rect.size = (256*self.scale, 256*self.scale)

    def on_touch_down(self, touch):
        self.touches.append(touch)
        if len(self.touches) == 2:
            x = touch.pos[0] - self.touches[0].pos[0]
            y = touch.pos[1] - self.touches[0].pos[1]
            self.cur_dist = x*x + y*y

    def on_touch_move(self, touch):
        if len(self.touches) == 2:
            print 'Zooming'
            if touch == self.touches[0]:
                print 'First touch moving'
                touch2 = self.touches[1]
            else:
                print 'Second touch moving'
                touch2 = self.touches[0]
            x = touch.pos[0] - touch2.pos[0]
            y = touch.pos[1] - touch2.pos[1]
            new_dist = x*x + y*y
            if (new_dist < self.cur_dist) and (self.scale > 0.5):
                self.scale *= 0.9
            elif self.scale < 4.0:
                self.scale *= 1.1
            self.cur_dist = new_dist
            self.redraw()

    def on_touch_up(self, touch):
        self.touches.remove(touch)

class DemoApp(App):

    def build(self):
        return TileWidget()

if __name__ == "__main__":
    DemoApp().run()
